@@ -1,13 +1,13 @@
 #' Bayes Factors (BF) for Order Restricted Models
 #'
 #' This method computes Bayes factors for comparing a model with an order restrictions on its parameters
-#' with the fully unrestricted model. \emph{Note that this method should only be used for confirmatory analyses}.
+#' with the fully unrestricted model. *Note that this method should only be used for confirmatory analyses*.
 #' \cr \cr
-#' The \code{bf_*} function is an alias of the main function.
+#' The `bf_*` function is an alias of the main function.
 #' \cr \cr
-#' \strong{For more info, in particular on specifying correct priors for factors with more than 2 levels, see \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.}
+#' \strong{For more info, in particular on specifying correct priors for factors with more than 2 levels, see [the Bayes factors vignette](https://easystats.github.io/bayestestR/articles/bayes_factors.html).}
 #'
-#' @param posterior A \code{stanreg} / \code{brmsfit} object, \code{emmGrid} or a data frame - representing a posterior distribution(s) from (see Details).
+#' @param posterior A `stanreg` / `brmsfit` object, `emmGrid` or a data frame - representing a posterior distribution(s) from (see Details).
 #' @param hypothesis A character vector specifying the restrictions as logical conditions (see examples below).
 #' @param prior An object representing a prior distribution (see Details).
 #' @inheritParams hdi
@@ -16,14 +16,14 @@
 #' models by setting an order restriction on the prior and posterior distributions
 #' (\cite{Morey & Wagenmakers, 2013}).
 #' \cr\cr
-#' (Though it is possible to use \code{bayesfactor_restricted()} to test interval restrictions,
+#' (Though it is possible to use `bayesfactor_restricted()` to test interval restrictions,
 #' it is more suitable for testing order restrictions; see examples).
 #'
-#' @inheritSection bayesfactor_parameters Setting the correct \code{prior}
+#' @inheritSection bayesfactor_parameters Setting the correct `prior`
 #'
 #' @inheritSection bayesfactor_parameters Interpreting Bayes Factors
 #'
-#' @return A data frame containing the Bayes factor representing evidence \emph{against} the un-restricted model.
+#' @return A data frame containing the (log) Bayes factor representing evidence *against* the un-restricted model.
 #'
 #' @examples
 #' library(bayestestR)
@@ -50,7 +50,7 @@
 #' # ---------------
 #' if (require("rstanarm") && require("emmeans")) {
 #'   fit_stan <- stan_glm(mpg ~ wt + cyl + am,
-#'     data = mtcars
+#'     data = mtcars, refresh = 0
 #'   )
 #'   hyps <- c(
 #'     "am > 0 & cyl < 0",
@@ -64,7 +64,7 @@
 #'   # replicating http://bayesfactor.blogspot.com/2015/01/multiple-comparisons-with-bayesfactor-2.html
 #'   disgust_data <- read.table(url("http://www.learnbayes.org/disgust_example.txt"), header = TRUE)
 #'
-#'   contrasts(disgust_data$condition) <- contr.bayes # see vignette
+#'   contrasts(disgust_data$condition) <- contr.orthonorm # see vignette
 #'   fit_model <- stan_glm(score ~ condition, data = disgust_data, family = gaussian())
 #'
 #'   em_condition <- emmeans(fit_model, ~condition)
@@ -73,8 +73,8 @@
 #'   bayesfactor_restricted(em_condition, prior = fit_model, hypothesis = hyps)
 #'   # > # Bayes Factor (Order-Restriction)
 #'   # >
-#'   # >                          Hypothesis P(Prior) P(Posterior) Bayes Factor
-#'   # >  lemon < control & control < sulfur     0.17         0.75         4.49
+#'   # >                          Hypothesis P(Prior) P(Posterior)   BF
+#'   # >  lemon < control & control < sulfur     0.17         0.75 4.49
 #'   # > ---
 #'   # > Bayes factors for the restricted model vs. the un-restricted model.
 #' }
@@ -121,6 +121,22 @@ bayesfactor_restricted.stanreg <- function(posterior, hypothesis, prior = NULL,
 #' @export
 bayesfactor_restricted.brmsfit <- bayesfactor_restricted.stanreg
 
+#' @rdname bayesfactor_restricted
+#' @export
+bayesfactor_restricted.blavaan <- function(posterior, hypothesis, prior = NULL,
+                                           verbose = TRUE, ...) {
+  samps <- .clean_priors_and_posteriors(posterior, prior,
+    verbose = verbose
+  )
+
+  # Get savage-dickey BFs
+  bayesfactor_restricted.data.frame(
+    posterior = samps$posterior, prior = samps$prior,
+    hypothesis = hypothesis
+  )
+}
+
+
 #' @rdname bayesfactor_restricted
 #' @export
 bayesfactor_restricted.emmGrid <- function(posterior, hypothesis, prior = NULL,
@@ -173,9 +189,9 @@ bayesfactor_restricted.data.frame <- function(posterior, hypothesis, prior = NUL
   BF <- posterior_p / prior_p
   res <- data.frame(
     Hypothesis = hypothesis,
-    Prior_prob = prior_p,
-    Posterior_prob = posterior_p,
-    BF = BF
+    p_prior = prior_p,
+    p_posterior = posterior_p,
+    log_BF = log(BF)
   )
 
   class(res) <- unique(c(
