@@ -1,16 +1,30 @@
 #' Posteriors Sampling Diagnostic
 #'
-#' Extract diagnostic metrics (Effective Sample Size (\code{ESS}), \code{Rhat} and Monte Carlo Standard Error \code{MCSE}).
+#' Extract diagnostic metrics (Effective Sample Size (`ESS`), `Rhat` and Monte
+#' Carlo Standard Error `MCSE`).
 #'
 #' @param posteriors A stanreg or brms model.
-#' @param diagnostic Diagnostic metrics to compute.  Character (vector) or list with one or more of these options: \code{"ESS"}, \code{"Rhat"}, \code{"MCSE"} or \code{"all"}.
+#' @param diagnostic Diagnostic metrics to compute.  Character (vector) or list
+#'   with one or more of these options: `"ESS"`, `"Rhat"`, `"MCSE"` or `"all"`.
 #'
 #' @details
-#'   \strong{Effective Sample (ESS)} should be as large as possible, although for most applications, an effective sample size greater than 1000 is sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the number of independent samples with the same estimation power as the N autocorrelated samples. It is is a measure of \dQuote{how much independent information there is in autocorrelated chains} (\cite{Kruschke 2015, p182-3}).
+#'   **Effective Sample (ESS)** should be as large as possible, although for
+#'   most applications, an effective sample size greater than 1000 is sufficient
+#'   for stable estimates (Bürkner, 2017). The ESS corresponds to the number of
+#'   independent samples with the same estimation power as the N autocorrelated
+#'   samples. It is is a measure of \dQuote{how much independent information
+#'   there is in autocorrelated chains} (\cite{Kruschke 2015, p182-3}).
 #'   \cr \cr
-#'   \strong{Rhat} should be the closest to 1. It should not be larger than 1.1 (\cite{Gelman and Rubin, 1992}) or 1.01 (\cite{Vehtari et al., 2019}). The split R-hat statistic quantifies the consistency of an ensemble of Markov chains.
+#'   **Rhat** should be the closest to 1. It should not be larger than 1.1
+#'   (\cite{Gelman and Rubin, 1992}) or 1.01 (\cite{Vehtari et al., 2019}). The
+#'   split Rhat statistic quantifies the consistency of an ensemble of Markov
+#'   chains.
 #'   \cr \cr
-#'   \strong{Monte Carlo Standard Error (MCSE)} is another measure of accuracy of the chains. It is defined as standard deviation of the chains divided by their effective sample size (the formula for \code{mcse()} is from Kruschke 2015, p. 187). The MCSE \dQuote{provides a quantitative suggestion of how big the estimation noise is}.
+#'   **Monte Carlo Standard Error (MCSE)** is another measure of accuracy of the
+#'   chains. It is defined as standard deviation of the chains divided by their
+#'   effective sample size (the formula for `mcse()` is from Kruschke 2015, p.
+#'   187). The MCSE \dQuote{provides a quantitative suggestion of how big the
+#'   estimation noise is}.
 #'
 #'
 #' @examples
@@ -41,7 +55,6 @@ diagnostic_posterior <- function(posteriors, diagnostic = c("ESS", "Rhat"), ...)
 }
 
 
-
 #' @export
 diagnostic_posterior.numeric <- function(posteriors, diagnostic = c("ESS", "Rhat"), ...) {
   stop("`diagnostic_posterior` only works with rstanarm or brms models.")
@@ -54,7 +67,6 @@ diagnostic_posterior.data.frame <- diagnostic_posterior.numeric
 diagnostic_posterior.BFBayesFactor <- diagnostic_posterior.numeric
 
 
-
 #' @inheritParams insight::get_parameters.BFBayesFactor
 #' @inheritParams insight::get_parameters
 #' @rdname diagnostic_posterior
@@ -64,7 +76,13 @@ diagnostic_posterior.stanreg <- function(posteriors, diagnostic = "all", effects
   # Find parameters
   effects <- match.arg(effects)
   component <- match.arg(component)
-  params <- insight::find_parameters(posteriors, effects = effects, component = component, parameters = parameters, flatten = TRUE)
+  params <- insight::find_parameters(
+    posteriors,
+    effects = effects,
+    component = component,
+    parameters = parameters,
+    flatten = TRUE
+  )
 
   # If no diagnostic
   if (is.null(diagnostic)) {
@@ -106,11 +124,21 @@ diagnostic_posterior.stanreg <- function(posteriors, diagnostic = "all", effects
 #' @inheritParams insight::get_parameters
 #' @rdname diagnostic_posterior
 #' @export
-diagnostic_posterior.stanmvreg <- function(posteriors, diagnostic = "all", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+diagnostic_posterior.stanmvreg <- function(posteriors,
+                                           diagnostic = "all",
+                                           effects = c("fixed", "random", "all"),
+                                           parameters = NULL,
+                                           ...) {
+
 
   # Find parameters
   effects <- match.arg(effects)
-  all_params <- insight::find_parameters(posteriors, effects = effects, parameters = parameters, flatten = FALSE)
+  all_params <- insight::find_parameters(
+    posteriors,
+    effects = effects,
+    parameters = parameters,
+    flatten = FALSE
+  )
 
   params <- unlist(lapply(names(all_params), function(i) {
     all_params[[i]]$sigma <- NULL
@@ -162,7 +190,13 @@ diagnostic_posterior.stanmvreg <- function(posteriors, diagnostic = "all", effec
 #' @inheritParams insight::get_parameters
 #' @rdname diagnostic_posterior
 #' @export
-diagnostic_posterior.brmsfit <- function(posteriors, diagnostic = "all", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
+diagnostic_posterior.brmsfit <- function(posteriors,
+                                         diagnostic = "all",
+                                         effects = c("fixed", "random", "all"),
+                                         component = c("conditional", "zi", "zero_inflated", "all"),
+                                         parameters = NULL,
+                                         ...) {
+
 
   # Find parameters
   effects <- match.arg(effects)
@@ -187,13 +221,11 @@ diagnostic_posterior.brmsfit <- function(posteriors, diagnostic = "all", effects
     if ("Rhat" %in% diagnostic) diagnostic <- c(diagnostic, "khat")
   }
 
-  if (!requireNamespace("rstan", quietly = TRUE)) {
-    stop("Package 'rstan' required for this function to work. Please install it by running `install.packages('rstan')`.")
-  }
+  insight::check_if_installed("rstan")
 
   # Get indices and rename
   diagnostic_df <- as.data.frame(rstan::summary(posteriors$fit)$summary)
-  diagnostic_df$Parameter <- make.names(row.names(diagnostic_df))
+  diagnostic_df$Parameter <- row.names(diagnostic_df)
   diagnostic_df$ESS <- diagnostic_df$n_eff
   # special handling for MCSE, due to some parameters (like lp__) missing in rows
   MCSE <- mcse(posteriors, effects = "all", component = "all")
@@ -213,7 +245,6 @@ diagnostic_posterior.brmsfit <- function(posteriors, diagnostic = "all", effects
 }
 
 
-
 #' @inheritParams insight::get_parameters
 #' @export
 diagnostic_posterior.stanfit <- function(posteriors, diagnostic = "all", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
@@ -233,11 +264,12 @@ diagnostic_posterior.stanfit <- function(posteriors, diagnostic = "all", effects
     diagnostic <- c("ESS", "Rhat", "MCSE")
   }
 
-  if (!requireNamespace("rstan", quietly = TRUE)) {
-    stop("Package 'rstan' required for this function to work. Please install it.")
-  }
+  insight::check_if_installed("rstan")
 
-  all_params <- insight::find_parameters(posteriors, effects = effects, flatten = TRUE)
+  all_params <- insight::find_parameters(posteriors,
+    effects = effects,
+    flatten = TRUE
+  )
 
   diagnostic_df <- data.frame(
     Parameter = all_params,
@@ -247,9 +279,11 @@ diagnostic_posterior.stanfit <- function(posteriors, diagnostic = "all", effects
   if ("ESS" %in% diagnostic) {
     diagnostic_df$ESS <- effective_sample(posteriors, effects = effects)$ESS
   }
+
   if ("MCSE" %in% diagnostic) {
     diagnostic_df$MCSE <- mcse(posteriors, effects = effects)$MCSE
   }
+
   if ("Rhat" %in% diagnostic) {
     s <- as.data.frame(rstan::summary(posteriors)$summary)
     diagnostic_df$Rhat <- s[rownames(s) %in% all_params, ]$Rhat
@@ -261,3 +295,51 @@ diagnostic_posterior.stanfit <- function(posteriors, diagnostic = "all", effects
   # Select rows
   diagnostic_df[diagnostic_df$Parameter %in% params, ]
 }
+
+
+#' @export
+diagnostic_posterior.blavaan <- function(posteriors, diagnostic = "all", ...) {
+
+  # Find parameters
+  params <- suppressWarnings(insight::find_parameters(posteriors, flatten = TRUE))
+
+  out <- data.frame("Parameter" = params)
+
+  # If no diagnostic
+  if (is.null(diagnostic)) {
+    return(out)
+  }
+
+  diagnostic <- match.arg(diagnostic, c("ESS", "Rhat", "MCSE", "all"), several.ok = TRUE)
+  if ("all" %in% diagnostic) {
+    diagnostic <- c("ESS", "Rhat", "MCSE")
+  } else {
+    diagnostic <- c(diagnostic)
+    if ("Rhat" %in% diagnostic) diagnostic <- c(diagnostic, "khat")
+  }
+
+  # Get indices
+  if ("Rhat" %in% diagnostic) {
+    insight::check_if_installed("blavaan")
+
+    Rhat <- blavaan::blavInspect(posteriors, what = "psrf")
+    Rhat <- data.frame(
+      Parameter = colnames(insight::get_parameters(posteriors)),
+      Rhat = Rhat
+    )
+    out <- merge(out, Rhat, by = "Parameter", all = TRUE)
+  }
+
+  if ("ESS" %in% diagnostic) {
+    ESS <- effective_sample(posteriors)
+    out <- merge(out, ESS, by = "Parameter", all = TRUE)
+  }
+
+
+  if ("MCSE" %in% diagnostic) {
+    MCSE <- mcse(posteriors)
+    out <- merge(out, MCSE, by = "Parameter", all = TRUE)
+  }
+
+  unique(out)
+}
