@@ -1,36 +1,36 @@
 #' Test for Practical Equivalence
 #'
-#' Perform a \strong{Test for Practical Equivalence} for Bayesian and frequentist models.
+#' Perform a **Test for Practical Equivalence** for Bayesian and frequentist models.
 #'
 #' Documentation is accessible for:
 #' \itemize{
-#'   \item \href{https://easystats.github.io/bayestestR/reference/equivalence_test.html}{Bayesian models}
-#'   \item \href{https://easystats.github.io/parameters/reference/equivalence_test.lm.html}{Frequentist models}
+#'   \item [Bayesian models](https://easystats.github.io/bayestestR/reference/equivalence_test.html)
+#'   \item [Frequentist models](https://easystats.github.io/parameters/reference/equivalence_test.lm.html)
 #' }
 #'
-#' For Bayesian models, the \strong{Test for Practical Equivalence} is based on the \emph{"HDI+ROPE decision rule"} (\cite{Kruschke, 2014, 2018}) to check whether parameter values should be accepted or rejected against an explicitly formulated "null hypothesis" (i.e., a ROPE). In other words, it checks the percentage of the 89\% \link[=hdi]{HDI} that is the null region (the ROPE). If this percentage is sufficiently low, the null hypothesis is rejected. If this percentage is sufficiently high, the null hypothesis is accepted.
+#' For Bayesian models, the **Test for Practical Equivalence** is based on the *"HDI+ROPE decision rule"* (\cite{Kruschke, 2014, 2018}) to check whether parameter values should be accepted or rejected against an explicitly formulated "null hypothesis" (i.e., a ROPE). In other words, it checks the percentage of the `89%` [HDI][hdi] that is the null region (the ROPE). If this percentage is sufficiently low, the null hypothesis is rejected. If this percentage is sufficiently high, the null hypothesis is accepted.
 #'
 #'
 #' @inheritParams rope
 #'
-#' @details Using the \link[=rope]{ROPE} and the \link[=hdi]{HDI}, \cite{Kruschke (2018)}
-#'   suggests using the percentage of the 95\% (or 89\%, considered more stable)
+#' @details Using the [ROPE][rope] and the [HDI][hdi], \cite{Kruschke (2018)}
+#'   suggests using the percentage of the `95%` (or `89%`, considered more stable)
 #'   HDI that falls within the ROPE as a decision rule. If the HDI
 #'   is completely outside the ROPE, the "null hypothesis" for this parameter is
 #'   "rejected". If the ROPE completely covers the HDI, i.e., all most credible
 #'   values of a parameter are inside the region of practical equivalence, the
 #'   null hypothesis is accepted. Else, it’s undecided whether to accept or
-#'   reject the null hypothesis. If the full ROPE is used (i.e., 100\% of the
+#'   reject the null hypothesis. If the full ROPE is used (i.e., `100%` of the
 #'   HDI), then the null hypothesis is rejected or accepted if the percentage
-#'   of the posterior within the ROPE is smaller than to 2.5\% or greater than
-#'   97.5\%. Desirable results are low proportions inside the ROPE  (the closer
+#'   of the posterior within the ROPE is smaller than to `2.5%` or greater than
+#'   `97.5%`. Desirable results are low proportions inside the ROPE  (the closer
 #'   to zero the better).
 #'   \cr \cr
 #'   Some attention is required for finding suitable values for the ROPE limits
-#'   (argument \code{range}). See 'Details' in \code{\link[=rope_range]{rope_range()}}
+#'   (argument `range`). See 'Details' in [`rope_range()`][rope_range]
 #'   for further information.
 #'   \cr \cr
-#'   \strong{Multicollinearity: Non-independent covariates}
+#'   **Multicollinearity: Non-independent covariates**
 #'   \cr \cr
 #'   When parameters show strong correlations, i.e. when covariates are not
 #'   independent, the joint parameter distributions may shift towards or
@@ -41,7 +41,7 @@
 #'   parameters, which may either move further towards "rejection" or away
 #'   from it (\cite{Kruschke 2014, 340f}).
 #'   \cr \cr
-#'   \code{equivalence_test()} performs a simple check for pairwise correlations
+#'   `equivalence_test()` performs a simple check for pairwise correlations
 #'   between parameters, but as there can be collinearity between more than two variables,
 #'   a first step to check the assumptions of this hypothesis testing is to look
 #'   at different pair plots. An even more sophisticated check is the projection
@@ -56,17 +56,17 @@
 #'
 #' @return A data frame with following columns:
 #'   \itemize{
-#'     \item \code{Parameter} The model parameter(s), if \code{x} is a model-object. If \code{x} is a vector, this column is missing.
-#'     \item \code{CI} The probability of the HDI.
-#'     \item \code{ROPE_low}, \code{ROPE_high} The limits of the ROPE. These values are identical for all parameters.
-#'     \item \code{ROPE_Percentage} The proportion of the HDI that lies inside the ROPE.
-#'     \item \code{ROPE_Equivalence} The "test result", as character. Either "rejected", "accepted" or "undecided".
-#'     \item \code{HDI_low} , \code{HDI_high} The lower and upper HDI limits for the parameters.
+#'     \item `Parameter` The model parameter(s), if `x` is a model-object. If `x` is a vector, this column is missing.
+#'     \item `CI` The probability of the HDI.
+#'     \item `ROPE_low`, `ROPE_high` The limits of the ROPE. These values are identical for all parameters.
+#'     \item `ROPE_Percentage` The proportion of the HDI that lies inside the ROPE.
+#'     \item `ROPE_Equivalence` The "test result", as character. Either "rejected", "accepted" or "undecided".
+#'     \item `HDI_low` , `HDI_high` The lower and upper HDI limits for the parameters.
 #'   }
 #'
-#' @note There is a \code{print()}-method with a \code{digits}-argument to control
+#' @note There is a `print()`-method with a `digits`-argument to control
 #'   the amount of digits in the output, and there is a
-#'   \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method}
+#'   [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html)
 #'   to visualize the results from the equivalence-test (for models only).
 #'
 #' @examples
@@ -103,8 +103,6 @@
 #' equivalence_test(bf)
 #' equivalence_test(bf, ci = c(.50, .99))
 #' }
-#'
-#' @importFrom insight print_color
 #' @export
 equivalence_test <- function(x, ...) {
   UseMethod("equivalence_test")
@@ -123,7 +121,7 @@ equivalence_test.default <- function(x, ...) {
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.numeric <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+equivalence_test.numeric <- function(x, range = "default", ci = 0.95, verbose = TRUE, ...) {
   rope_data <- rope(x, range = range, ci = ci)
   out <- as.data.frame(rope_data)
 
@@ -153,7 +151,7 @@ equivalence_test.numeric <- function(x, range = "default", ci = .89, verbose = T
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.data.frame <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+equivalence_test.data.frame <- function(x, range = "default", ci = 0.95, verbose = TRUE, ...) {
   l <- .compact_list(lapply(
     x,
     equivalence_test,
@@ -178,7 +176,7 @@ equivalence_test.data.frame <- function(x, range = "default", ci = .89, verbose
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.emmGrid <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+equivalence_test.emmGrid <- function(x, range = "default", ci = 0.95, verbose = TRUE, ...) {
   xdf <- insight::get_parameters(x)
 
   out <- equivalence_test(xdf, range = range, ci = ci, verbose = verbose, ...)
@@ -192,7 +190,7 @@ equivalence_test.emm_list <- equivalence_test.emmGrid
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
+equivalence_test.BFBayesFactor <- function(x, range = "default", ci = 0.95, verbose = TRUE, ...) {
   out <- equivalence_test(insight::get_parameters(x), range = range, ci = ci, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -201,16 +199,15 @@ equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbo
 
 
 
-#' @importFrom stats sd
 #' @keywords internal
-.equivalence_test_models <- function(x, range = "default", ci = .89, effects = "fixed", component = "conditional", parameters = NULL, verbose = TRUE) {
+.equivalence_test_models <- function(x, range = "default", ci = 0.95, effects = "fixed", component = "conditional", parameters = NULL, verbose = TRUE) {
   if (all(range == "default")) {
     range <- rope_range(x)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
 
-  if (verbose) .check_multicollinearity(x)
+  if (verbose && !inherits(x, "blavaan")) .check_multicollinearity(x)
   params <- insight::get_parameters(x, component = component, effects = effects, parameters = parameters)
 
   l <- sapply(
@@ -236,12 +233,17 @@ equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbo
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.stanreg <- function(x, range = "default", ci = .89, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.stanreg <- function(x, range = "default", ci = 0.95, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
   out <- .equivalence_test_models(x, range, ci, effects, component, parameters, verbose)
-  out <- merge(out, insight::clean_parameters(x)[, c("Parameter", "Effects", "Cleaned_Parameter")], by = "Parameter", sort = FALSE)
+
+  out <- .prepare_output(
+    out,
+    insight::clean_parameters(x),
+    inherits(x, "stanmvreg")
+  )
 
   class(out) <- unique(c("equivalence_test", "see_equivalence_test", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -252,15 +254,23 @@ equivalence_test.stanreg <- function(x, range = "default", ci = .89, effects = c
 #' @export
 equivalence_test.stanfit <- equivalence_test.stanreg
 
+#' @export
+equivalence_test.blavaan <- equivalence_test.stanreg
+
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.brmsfit <- function(x, range = "default", ci = .89, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.brmsfit <- function(x, range = "default", ci = 0.95, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
   out <- .equivalence_test_models(x, range, ci, effects, component, parameters, verbose)
-  out <- merge(out, insight::clean_parameters(x)[, c("Parameter", "Effects", "Component", "Cleaned_Parameter")], by = "Parameter", sort = FALSE)
+
+  out <- .prepare_output(
+    out,
+    insight::clean_parameters(x),
+    inherits(x, "stanmvreg")
+  )
 
   class(out) <- unique(c("equivalence_test", "see_equivalence_test", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -270,7 +280,7 @@ equivalence_test.brmsfit <- function(x, range = "default", ci = .89, effects = c
 
 
 #' @export
-equivalence_test.sim.merMod <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.sim.merMod <- function(x, range = "default", ci = 0.95, parameters = NULL, verbose = TRUE, ...) {
   out <- .equivalence_test_models(x, range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -281,7 +291,7 @@ equivalence_test.sim <- equivalence_test.sim.merMod
 
 
 #' @export
-equivalence_test.mcmc <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.mcmc <- function(x, range = "default", ci = 0.95, parameters = NULL, verbose = TRUE, ...) {
   out <- .equivalence_test_models(as.data.frame(x), range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -289,15 +299,25 @@ equivalence_test.mcmc <- function(x, range = "default", ci = .89, parameters = N
 
 
 #' @export
-equivalence_test.bcplm <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.bcplm <- function(x, range = "default", ci = 0.95, parameters = NULL, verbose = TRUE, ...) {
   out <- .equivalence_test_models(insight::get_parameters(x), range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
+#' @export
+equivalence_test.blrm <- equivalence_test.bcplm
 
 #' @export
-equivalence_test.bamlss <- function(x, range = "default", ci = .89, component = c("all", "conditional", "location"), parameters = NULL, verbose = TRUE, ...) {
+equivalence_test.mcmc.list <- equivalence_test.bcplm
+
+#' @export
+equivalence_test.bayesQR <- equivalence_test.bcplm
+
+
+
+#' @export
+equivalence_test.bamlss <- function(x, range = "default", ci = 0.95, component = c("all", "conditional", "location"), parameters = NULL, verbose = TRUE, ...) {
   component <- match.arg(component)
   out <- .equivalence_test_models(insight::get_parameters(x, component = component), range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
