@@ -1,26 +1,38 @@
 #' Density Estimation
 #'
-#' This function is a wrapper over different methods of density estimation. By default, it uses the base R \code{density} with by default uses a different smoothing bandwidth (\code{"SJ"}) from the legacy default implemented the base R \code{density} function (\code{"nrd0"}). However, Deng \& Wickham suggest that \code{method = "KernSmooth"} is the fastest and the most accurate.
+#' This function is a wrapper over different methods of density estimation. By default, it uses the base R `density` with by default uses a different smoothing bandwidth (`"SJ"`) from the legacy default implemented the base R `density` function (`"nrd0"`). However, Deng \& Wickham suggest that `method = "KernSmooth"` is the fastest and the most accurate.
 #'
 #' @inheritParams hdi
 #' @inheritParams stats::density
-#' @param bw See the eponymous argument in \code{density}. Here, the default has been changed for \code{"SJ"}, which is recommended.
-#' @param method Density estimation method. Can be \code{"kernel"} (default), \code{"logspline"} or \code{"KernSmooth"}.
-#' @param precision Number of points of density data. See the \code{n} parameter in \code{density}.
-#' @param extend Extend the range of the x axis by a factor of \code{extend_scale}.
-#' @param extend_scale Ratio of range by which to extend the x axis. A value of \code{0.1} means that the x axis will be extended by \code{1/10} of the range of the data.
-#' @param group_by Optional character vector. If not \code{NULL} and \code{x} is a data frame, density estimation is performed for each group (subset) indicated by \code{group_by}.
+#' @param bw See the eponymous argument in `density`. Here, the default has been changed for `"SJ"`, which is recommended.
+#' @param ci The confidence interval threshold. Only used when `method = "kernel"`.
+#' @param method Density estimation method. Can be `"kernel"` (default), `"logspline"` or `"KernSmooth"`.
+#' @param precision Number of points of density data. See the `n` parameter in `density`.
+#' @param extend Extend the range of the x axis by a factor of `extend_scale`.
+#' @param extend_scale Ratio of range by which to extend the x axis. A value of `0.1` means that the x axis will be extended by `1/10` of the range of the data.
+#' @param group_by Optional character vector. If not `NULL` and `x` is a data frame, density estimation is performed for each group (subset) indicated by `group_by`.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' library(bayestestR)
 #'
 #' set.seed(1)
-#' x <- rnorm(250, 1)
+#' x <- rnorm(250, mean = 1)
 #'
-#' # Methods
-#' density_kernel <- estimate_density(x, method = "kernel")
+#' # Basic usage
+#' density_kernel <- estimate_density(x) # default method is "kernel"
+#'
+#' hist(x, prob = TRUE)
+#' lines(density_kernel$x, density_kernel$y, col = "black", lwd = 2)
+#' lines(density_kernel$x, density_kernel$CI_low, col = "gray", lty = 2)
+#' lines(density_kernel$x, density_kernel$CI_high, col = "gray", lty = 2)
+#' legend("topright",
+#'   legend = c("Estimate", "95% CI"),
+#'   col = c("black", "gray"), lwd = 2, lty = c(1, 2)
+#' )
+#'
+#' # Other Methods
 #' density_logspline <- estimate_density(x, method = "logspline")
 #' density_KernSmooth <- estimate_density(x, method = "KernSmooth")
 #' density_mixture <- estimate_density(x, method = "mixture")
@@ -39,8 +51,13 @@
 #' lines(density_extended$x, density_extended$y, col = "red", lwd = 3)
 #' lines(density_default$x, density_default$y, col = "black", lwd = 3)
 #'
+#' # Multiple columns
 #' df <- data.frame(replicate(4, rnorm(100)))
 #' head(estimate_density(df))
+#'
+#' # Grouped data
+#' estimate_density(iris, group_by = "Species")
+#' estimate_density(iris$Petal.Width, group_by = iris$Species)
 #' \dontrun{
 #' # rstanarm models
 #' # -----------------------------------------------
@@ -60,17 +77,14 @@
 #'
 #' @references Deng, H., & Wickham, H. (2011). Density estimation in R. Electronic publication.
 #'
-#' @importFrom stats density
-#' @importFrom utils install.packages
 #' @export
 estimate_density <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
   UseMethod("estimate_density")
 }
 
 
-#' @importFrom stats predict
 #' @keywords internal
-.estimate_density <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
+.estimate_density <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, ...) {
   method <- match.arg(tolower(method), c("kernel", "logspline", "kernsmooth", "smooth", "mixture", "mclust"))
 
   # Remove NA
@@ -89,61 +103,40 @@ estimate_density <- function(x, method = "kernel", precision = 2^10, extend = FA
 
   # Kernel
   if (method == "kernel") {
-    return(as.data.frame(density(x, n = precision, bw = bw, from = x_range[1], to = x_range[2], ...)))
-
+    kde <- .estimate_density_kernel(x, x_range, precision, bw, ci, ...)
     # Logspline
   } else if (method == "logspline") {
-    if (!requireNamespace("logspline")) {
-      if (interactive()) {
-        readline("Package \"logspline\" needed for this function. Press ENTER to install or ESCAPE to abort.")
-        install.packages("logspline")
-      } else {
-        stop("Package \"logspline\" needed for this function. Press run 'install.packages(\"logspline\")'.")
-      }
-    }
-
-    x_axis <- seq(x_range[1], x_range[2], length.out = precision)
-    y <- logspline::dlogspline(x_axis, logspline::logspline(x, ...), ...)
-    return(data.frame(x = x_axis, y = y))
-
+    kde <- .estimate_density_logspline(x, x_range, precision, ...)
     # KernSmooth
   } else if (method %in% c("kernsmooth", "smooth")) {
-    if (!requireNamespace("KernSmooth")) {
-      if (interactive()) {
-        readline("Package \"KernSmooth\" needed for this function. Press ENTER to install or ESCAPE to abort.")
-        install.packages("KernSmooth")
-      } else {
-        stop("Package \"KernSmooth\" needed for this function. Press run 'install.packages(\"KernSmooth\")'.")
-      }
-    }
-    return(as.data.frame(KernSmooth::bkde(x, range.x = x_range, gridsize = precision, truncate = TRUE, ...)))
-
-    # Mixturre
+    kde <- .estimate_density_KernSmooth(x, x_range, precision, ...)
+    # Mixture
   } else if (method %in% c("mixture", "mclust")) {
-    if (!requireNamespace("mclust")) {
-      if (interactive()) {
-        readline("Package \"mclust\" needed for this function. Press ENTER to install or ESCAPE to abort.")
-        install.packages("KernSmooth")
-      } else {
-        stop("Package \"mclust\" needed for this function. Press run 'install.packages(\"mclust\")'.")
-      }
-    }
-
-    x_axis <- seq(x_range[1], x_range[2], length.out = precision)
-    y <- predict(mclust::densityMclust(x, verbose = FALSE), newdata = x_axis)
-    return(data.frame(x = x_axis, y = y))
+    kde <- .estimate_density_mixture(x, x_range, precision, ...)
   } else {
     stop("method should be one of 'kernel', 'logspline', 'KernSmooth' or 'mixture'.")
   }
+  kde
 }
 
 
 
+# Methods -----------------------------------------------------------------
+
+
 
 
 #' @export
-estimate_density.numeric <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
-  out <- .estimate_density(x, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
+estimate_density.numeric <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, group_by = NULL, ...) {
+  if (!is.null(group_by)) {
+    if (length(group_by) == 1) {
+      stop("`group_by` must be either the name of a group column if a data.frame is entered as input, or in this case (where a single vector was passed) a vector of same length.")
+    }
+    out <- estimate_density(data.frame(V1 = x, Group = group_by), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, group_by = "Group", ...)
+    out$Parameter <- NULL
+    return(out)
+  }
+  out <- .estimate_density(x, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, ...)
   class(out) <- .set_density_class(out)
   out
 }
@@ -154,13 +147,13 @@ estimate_density.numeric <- function(x, method = "kernel", precision = 2^10, ext
 
 #' @rdname estimate_density
 #' @export
-estimate_density.data.frame <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", group_by = NULL, ...) {
+estimate_density.data.frame <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, group_by = NULL, ...) {
   if (is.null(group_by)) {
-    out <- .estimate_density_df(x = x, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
+    out <- .estimate_density_df(x = x, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, ...)
   } else {
     xlist <- split(x, x[group_by])
     out <- lapply(names(xlist), function(group) {
-      dens <- .estimate_density_df(x = xlist[[group]], method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
+      dens <- .estimate_density_df(x = xlist[[group]], method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, ...)
       dens$Group <- group
       dens
     })
@@ -171,9 +164,9 @@ estimate_density.data.frame <- function(x, method = "kernel", precision = 2^10,
   out
 }
 
-.estimate_density_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
+.estimate_density_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, ...) {
   x <- .select_nums(x)
-  out <- sapply(x, estimate_density, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, simplify = FALSE)
+  out <- sapply(x, estimate_density, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, simplify = FALSE)
   for (i in names(out)) {
     out[[i]]$Parameter <- i
   }
@@ -185,20 +178,21 @@ estimate_density.data.frame <- function(x, method = "kernel", precision = 2^10,
 
 
 #' @export
-estimate_density.grouped_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
+estimate_density.grouped_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, ...) {
   groups <- .group_vars(x)
   ungrouped_x <- as.data.frame(x)
 
   xlist <- split(ungrouped_x, ungrouped_x[groups])
 
   out <- lapply(names(xlist), function(group) {
-    dens <- estimate_density(xlist[[group]], method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw)
+    dens <- estimate_density(xlist[[group]], method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci)
     dens$Group <- group
     dens
   })
   do.call(rbind, out)
 }
 
+
 #' @export
 estimate_density.emmGrid <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
   x <- insight::get_parameters(x)
@@ -217,7 +211,6 @@ estimate_density.emm_list <- estimate_density.emmGrid
 
 
 
-#' @importFrom insight get_parameters
 #' @export
 estimate_density.stanreg <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
@@ -233,9 +226,11 @@ estimate_density.stanreg <- function(x, method = "kernel", precision = 2^10, ext
 #' @export
 estimate_density.stanfit <- estimate_density.stanreg
 
+#' @export
+estimate_density.blavaan <- estimate_density.stanreg
+
 
 
-#' @importFrom insight get_parameters
 #' @export
 estimate_density.brmsfit <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
@@ -264,7 +259,6 @@ estimate_density.MCMCglmm <- function(x, method = "kernel", precision = 2^10, ex
 
 
 
-#' @importFrom insight get_parameters
 #' @export
 estimate_density.mcmc <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", parameters = NULL, ...) {
   out <- estimate_density(insight::get_parameters(x, parameters = parameters), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
@@ -277,10 +271,18 @@ estimate_density.mcmc <- function(x, method = "kernel", precision = 2^10, extend
 #' @export
 estimate_density.bayesQR <- estimate_density.mcmc
 
+#' @export
+estimate_density.blrm <- estimate_density.mcmc
 
 #' @export
 estimate_density.bcplm <- estimate_density.mcmc
 
+#' @export
+estimate_density.BGGM <- estimate_density.mcmc
+
+#' @export
+estimate_density.mcmc.list <- estimate_density.mcmc
+
 
 #' @export
 estimate_density.bamlss <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", component = c("all", "conditional", "location"), parameters = NULL, ...) {
@@ -310,7 +312,7 @@ as.data.frame.density <- function(x, ...) {
 
 #' Density Probability at a Given Value
 #'
-#' Compute the density value at a given point of a distribution (i.e., the value of the \code{y} axis of a value \code{x} of a distribution).
+#' Compute the density value at a given point of a distribution (i.e., the value of the `y` axis of a value `x` of a distribution).
 #'
 #' @param posterior Vector representing a posterior distribution.
 #' @param x The value of which to get the approximate probability.
@@ -321,7 +323,6 @@ as.data.frame.density <- function(x, ...) {
 #' posterior <- distribution_normal(n = 10)
 #' density_at(posterior, 0)
 #' density_at(posterior, c(0, 1))
-#' @importFrom stats approx density
 #' @export
 density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
   density <- estimate_density(posterior, precision = precision, method = method, ...)
@@ -333,6 +334,76 @@ density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
 
 
 
+# Different functions -----------------------------------------------------
+
+.estimate_density_kernel <- function(x, x_range, precision, bw, ci = 0.95, ...) {
+  # Get the kernel density estimation (KDE)
+  kde <- stats::density(x, n = precision, bw = bw, from = x_range[1], to = x_range[2], ...)
+  df <- as.data.frame(kde)
+
+  # Get CI (https://bookdown.org/egarpor/NP-UC3M/app-kde-ci.html)
+  if (!is.null(ci)) {
+    h <- kde$bw # Selected bandwidth
+    # R(K) for a normal
+    Rk <- 1 / (2 * sqrt(pi))
+    # Estimate the SD
+    sd_kde <- sqrt(df$y * Rk / (length(x) * h))
+    # CI with estimated variance
+    z_alpha <- stats::qnorm(ci)
+    df$CI_low <- df$y - z_alpha * sd_kde
+    df$CI_high <- df$y + z_alpha * sd_kde
+  }
+  df
+}
+
+
+
+
+.estimate_density_logspline <- function(x, x_range, precision, ...) {
+  if (!requireNamespace("logspline")) {
+    if (interactive()) {
+      readline("Package \"logspline\" needed for this function. Press ENTER to install or ESCAPE to abort.")
+      utils::install.packages("logspline")
+    } else {
+      stop("Package \"logspline\" needed for this function. Press run 'install.packages(\"logspline\")'.")
+    }
+  }
+
+  x_axis <- seq(x_range[1], x_range[2], length.out = precision)
+  y <- logspline::dlogspline(x_axis, logspline::logspline(x, ...), ...)
+  data.frame(x = x_axis, y = y)
+}
+
+
+.estimate_density_KernSmooth <- function(x, x_range, precision, ...) {
+  if (!requireNamespace("KernSmooth")) {
+    if (interactive()) {
+      readline("Package \"KernSmooth\" needed for this function. Press ENTER to install or ESCAPE to abort.")
+      utils::install.packages("KernSmooth")
+    } else {
+      stop("Package \"KernSmooth\" needed for this function. Press run 'install.packages(\"KernSmooth\")'.")
+    }
+  }
+  as.data.frame(KernSmooth::bkde(x, range.x = x_range, gridsize = precision, truncate = TRUE, ...))
+}
+
+
+.estimate_density_mixture <- function(x, x_range, precision, ...) {
+  if (!requireNamespace("mclust")) {
+    if (interactive()) {
+      readline("Package \"mclust\" needed for this function. Press ENTER to install or ESCAPE to abort.")
+      utils::install.packages("KernSmooth")
+    } else {
+      stop("Package \"mclust\" needed for this function. Press run 'install.packages(\"mclust\")'.")
+    }
+  }
+
+  x_axis <- seq(x_range[1], x_range[2], length.out = precision)
+  y <- stats::predict(mclust::densityMclust(x, verbose = FALSE, ...), newdata = x_axis, ...)
+  data.frame(x = x_axis, y = y)
+}
+
+
 # helper ----------------------------------------------------------
 
 .set_density_df_class <- function(out) {
