@@ -1,15 +1,15 @@
 #' Maximum A Posteriori probability estimate (MAP)
 #'
-#' Find the \strong{Highest Maximum A Posteriori probability estimate (MAP)} of a posterior, i.e., the value associated with the highest probability density (the "peak" of the posterior distribution). In other words, it is an estimation of the \emph{mode} for continuous parameters. Note that this function relies on \link{estimate_density}, which by default uses a different smoothing bandwidth (\code{"SJ"}) compared to the legacy default implemented the base R \link{density} function (\code{"nrd0"}).
+#' Find the **Highest Maximum A Posteriori probability estimate (MAP)** of a posterior, i.e., the value associated with the highest probability density (the "peak" of the posterior distribution). In other words, it is an estimation of the *mode* for continuous parameters. Note that this function relies on [estimate_density], which by default uses a different smoothing bandwidth (`"SJ"`) compared to the legacy default implemented the base R [density] function (`"nrd0"`).
 #'
 #' @inheritParams hdi
 #' @inheritParams estimate_density
 #'
-#' @return A numeric value if \code{posterior} is a vector. If \code{posterior}
+#' @return A numeric value if `posterior` is a vector. If `posterior`
 #' is a model-object, returns a data frame with following columns:
 #'   \itemize{
-#'     \item \code{Parameter} The model parameter(s), if \code{x} is a model-object. If \code{x} is a vector, this column is missing.
-#'     \item \code{MAP_Estimate} The MAP estimate for the posterior or each model parameter.
+#'     \item `Parameter` The model parameter(s), if `x` is a model-object. If `x` is a vector, this column is missing.
+#'     \item `MAP_Estimate` The MAP estimate for the posterior or each model parameter.
 #'   }
 #'
 #' @examples
@@ -31,7 +31,6 @@
 #' map_estimate(model)
 #' }
 #'
-#' @importFrom stats density
 #' @export
 map_estimate <- function(x, precision = 2^10, method = "kernel", ...) {
   UseMethod("map_estimate")
@@ -39,8 +38,6 @@ map_estimate <- function(x, precision = 2^10, method = "kernel", ...) {
 
 
 
-
-
 #' @rdname map_estimate
 #' @export
 map_estimate.numeric <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -60,7 +57,6 @@ map_estimate.numeric <- function(x, precision = 2^10, method = "kernel", ...) {
 }
 
 
-
 #' @rdname map_estimate
 #' @export
 map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -69,8 +65,48 @@ map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
 }
 
 
+#' @export
+map_estimate.BGGM <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.mcmc <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.bamlss <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.bcplm <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.blrm <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.mcmc.list <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
 
-#' @importFrom insight get_parameters
 #' @keywords internal
 .map_estimate_models <- function(x, precision, method, ...) {
   l <- sapply(x, map_estimate, precision = precision, method = method, simplify = FALSE, ...)
@@ -82,15 +118,15 @@ map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
     row.names = NULL
   )
 
+  out <- .add_clean_parameters_attribute(out, x)
   attr(out, "MAP_density") <- sapply(l, attr, "MAP_density")
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
   attr(out, "centrality") <- "map"
   class(out) <- unique(c("map_estimate", "see_point_estimate", class(out)))
-
-  class(out) <- unique(c("map_estimate", class(out)))
   out
 }
 
+
 #' @rdname map_estimate
 #' @export
 map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
@@ -107,6 +143,9 @@ map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects
 #' @export
 map_estimate.stanfit <- map_estimate.stanreg
 
+#' @export
+map_estimate.blavaan <- map_estimate.stanreg
+
 
 #' @rdname map_estimate
 #' @export
@@ -121,7 +160,6 @@ map_estimate.brmsfit <- function(x, precision = 2^10, method = "kernel", effects
 }
 
 
-
 #' @rdname map_estimate
 #' @export
 map_estimate.data.frame <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -129,8 +167,6 @@ map_estimate.data.frame <- function(x, precision = 2^10, method = "kernel", ...)
 }
 
 
-
-
 #' @rdname map_estimate
 #' @export
 map_estimate.emmGrid <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -142,6 +178,18 @@ map_estimate.emmGrid <- function(x, precision = 2^10, method = "kernel", ...) {
 map_estimate.emm_list <- map_estimate.emmGrid
 
 
+#' @export
+map_estimate.get_predicted <- function(x, ...) {
+  if ("iterations" %in% names(attributes(x))) {
+    map_estimate(as.data.frame(t(attributes(x)$iterations)), ...)
+  } else {
+    stop("No iterations present in the output.")
+  }
+}
+
+# Methods -----------------------------------------------------------------
+
+
 
 #' @rdname as.numeric.p_direction
 #' @method as.numeric map_estimate
