@@ -5,9 +5,9 @@
 #' @inheritParams effective_sample
 #'
 #'
-#' @details \strong{Monte Carlo Standard Error (MCSE)} is another measure of
+#' @details **Monte Carlo Standard Error (MCSE)** is another measure of
 #' accuracy of the chains. It is defined as standard deviation of the chains
-#' divided by their effective sample size (the formula for \code{mcse()} is
+#' divided by their effective sample size (the formula for `mcse()` is
 #' from Kruschke 2015, p. 187). The MCSE \dQuote{provides a quantitative
 #' suggestion of how big the estimation noise is}.
 #'
@@ -21,8 +21,6 @@
 #' model <- stan_glm(mpg ~ wt + am, data = mtcars, chains = 1, refresh = 0)
 #' mcse(model)
 #' }
-#' @importFrom insight get_parameters
-#' @importFrom stats setNames
 #' @export
 mcse <- function(model, ...) {
   UseMethod("mcse")
@@ -87,8 +85,10 @@ mcse.stanreg <- function(model, effects = c("fixed", "random", "all"), component
 mcse.stanfit <- mcse.stanreg
 
 
+#' @export
+mcse.blavaan <- mcse.stanreg
+
 
-#' @importFrom stats sd na.omit
 #' @keywords internal
 .mcse <- function(params, ess) {
   # get standard deviations from posterior samples
