@@ -1,12 +1,12 @@
 #' Bayesian p-value based on the density at the Maximum A Posteriori (MAP)
 #'
-#' Compute a Bayesian equivalent of the \emph{p}-value, related to the odds that a parameter (described by its posterior distribution) has against the null hypothesis (\emph{h0}) using Mills' (2014, 2017) \emph{Objective Bayesian Hypothesis Testing} framework. It corresponds to the density value at 0 divided by the density at the Maximum A Posteriori (MAP).
+#' Compute a Bayesian equivalent of the *p*-value, related to the odds that a parameter (described by its posterior distribution) has against the null hypothesis (*h0*) using Mills' (2014, 2017) *Objective Bayesian Hypothesis Testing* framework. It corresponds to the density value at 0 divided by the density at the Maximum A Posteriori (MAP).
 #'
-#' @details Note that this method is sensitive to the density estimation \code{method} (see the section in the examples below).
+#' @details Note that this method is sensitive to the density estimation `method` (see the section in the examples below).
 #' \subsection{Strengths and Limitations}{
-#' \strong{Strengths:} Straightforward computation. Objective property of the posterior distribution.
+#' **Strengths:** Straightforward computation. Objective property of the posterior distribution.
 #' \cr \cr
-#' \strong{Limitations:} Limited information favoring the null hypothesis. Relates on density approximation. Indirect relationship between mathematical definition and interpretation. Only suitable for weak / very diffused priors.
+#' **Limitations:** Limited information favoring the null hypothesis. Relates on density approximation. Indirect relationship between mathematical definition and interpretation. Only suitable for weak / very diffused priors.
 #' }
 #'
 #' @inheritParams hdi
@@ -53,14 +53,13 @@
 #' summary(data$logspline)
 #' boxplot(data[c("KernSmooth", "logspline")])
 #' }
-#' @seealso \href{https://www.youtube.com/watch?v=Ip8Ci5KUVRc}{Jeff Mill's talk}
+#' @seealso [Jeff Mill's talk](https://www.youtube.com/watch?v=Ip8Ci5KUVRc)
 #'
 #' @references \itemize{
 #'   \item Makowski D, Ben-Shachar MS, Chen SHA, Lüdecke D (2019) Indices of Effect Existence and Significance in the Bayesian Framework. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
 #'   \item Mills, J. A. (2018). Objective Bayesian Precise Hypothesis Testing. University of Cincinnati.
 #' }
 #'
-#' @importFrom stats density
 #' @export
 p_map <- function(x, precision = 2^10, method = "kernel", ...) {
   UseMethod("p_map")
@@ -127,7 +126,6 @@ p_map.emm_list <- p_map.emmGrid
 
 
 
-#' @importFrom insight get_parameters
 #' @keywords internal
 .p_map_models <- function(x, precision, method, effects, component, parameters, ...) {
   p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, method = method, ...)
@@ -156,10 +154,15 @@ p_map.mcmc <- function(x, precision = 2^10, method = "kernel", parameters = NULL
 #' @export
 p_map.bcplm <- p_map.mcmc
 
+#' @export
+p_map.blrm <- p_map.mcmc
 
 #' @export
 p_map.mcmc.list <- p_map.mcmc
 
+#' @export
+p_map.BGGM <- p_map.mcmc
+
 
 
 #' @export
@@ -175,6 +178,7 @@ p_map.bamlss <- function(x, precision = 2^10, method = "kernel", component = c("
     ...
   )
 
+  out <- .add_clean_parameters_attribute(out, x)
   attr(out, "data") <- insight::get_parameters(x, parameters = parameters)
   out
 }
@@ -226,13 +230,15 @@ p_map.sim <- function(x, precision = 2^10, method = "kernel", parameters = NULL,
 p_map.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, method = method),
-    insight::clean_parameters(x),
+    cleaned_parameters,
     inherits(x, "stanmvreg")
   )
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("p_map", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -242,18 +248,24 @@ p_map.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("f
 p_map.stanfit <- p_map.stanreg
 
 
+#' @export
+p_map.blavaan <- p_map.stanreg
+
+
 
 #' @rdname p_map
 #' @export
 p_map.brmsfit <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, method = method, ...),
-    insight::clean_parameters(x)
+    cleaned_parameters
   )
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("p_map", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
