@@ -1,23 +1,23 @@
 #' Practical Significance (ps)
 #'
-#' Compute the probability of \strong{Practical Significance} (\strong{\emph{ps}}), which can be conceptualized as a unidirectional equivalence test. It returns the probability that effect is above a given threshold corresponding to a negligible effect in the median's direction. Mathematically, it is defined as the proportion of the posterior distribution of the median sign above the threshold.
+#' Compute the probability of **Practical Significance** (***ps***), which can be conceptualized as a unidirectional equivalence test. It returns the probability that effect is above a given threshold corresponding to a negligible effect in the median's direction. Mathematically, it is defined as the proportion of the posterior distribution of the median sign above the threshold.
 #'
 #' @inheritParams rope
-#' @param threshold The threshold value that separates significant from negligible effect. If \code{"default"}, the range is set to \code{0.1} if input is a vector, and based on \code{\link[=rope_range]{rope_range()}} if a Bayesian model is provided.
+#' @param threshold The threshold value that separates significant from negligible effect. If `"default"`, the range is set to `0.1` if input is a vector, and based on [`rope_range()`][rope_range] if a Bayesian model is provided.
 #'
 #' @return Values between 0 and 1 corresponding to the probability of practical significance (ps).
 #'
-#' @details \code{p_significance()} returns the proportion of a probability
-#'   distribution (\code{x}) that is outside a certain range (the negligible
-#'   effect, or ROPE, see argument \code{threshold}). If there are values of the
-#'   distribution both below and above the ROPE, \code{p_significance()} returns
+#' @details `p_significance()` returns the proportion of a probability
+#'   distribution (`x`) that is outside a certain range (the negligible
+#'   effect, or ROPE, see argument `threshold`). If there are values of the
+#'   distribution both below and above the ROPE, `p_significance()` returns
 #'   the higher probability of a value being outside the ROPE. Typically, this
 #'   value should be larger than 0.5 to indicate practical significance. However,
 #'   if the range of the negligible effect is rather large compared to the
-#'   range of the probability distribution \code{x}, \code{p_significance()}
+#'   range of the probability distribution `x`, `p_significance()`
 #'   will be less than 0.5, which indicates no clear practical significance.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' library(bayestestR)
@@ -156,7 +156,9 @@ p_significance.mcmc <- function(x, threshold = "default", ...) {
 
 #' @export
 p_significance.bamlss <- function(x, threshold = "default", component = c("all", "conditional", "location"), ...) {
-  p_significance(insight::get_parameters(x, component = component), threshold = threshold, ...)
+  out <- p_significance(insight::get_parameters(x, component = component), threshold = threshold, ...)
+  out <- .add_clean_parameters_attribute(out, x)
+  out
 }
 
 
@@ -165,17 +167,17 @@ p_significance.bcplm <- function(x, threshold = "default", ...) {
   p_significance(insight::get_parameters(x), threshold = threshold, ...)
 }
 
+#' @export
+p_significance.mcmc.list <- p_significance.bcplm
 
 #' @export
-p_significance.mcmc.list <- function(x, threshold = "default", ...) {
-  p_significance(insight::get_parameters(x), threshold = threshold, ...)
-}
-
+p_significance.bayesQR <- p_significance.bcplm
 
 #' @export
-p_significance.bayesQR <- function(x, threshold = "default", ...) {
-  p_significance(insight::get_parameters(x), threshold = threshold, ...)
-}
+p_significance.blrm <- p_significance.bcplm
+
+#' @export
+p_significance.BGGM <- p_significance.bcplm
 
 
 #' @rdname p_significance
@@ -209,8 +211,10 @@ p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed"
     threshold = threshold
   )
 
-  out <- .prepare_output(data, insight::clean_parameters(x), inherits(x, "stanmvreg"))
+  cleaned_parameters <- insight::clean_parameters(x)
+  out <- .prepare_output(data, cleaned_parameters, inherits(x, "stanmvreg"))
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- class(data)
@@ -222,6 +226,10 @@ p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed"
 p_significance.stanfit <- p_significance.stanreg
 
 
+#' @export
+p_significance.blavaan <- p_significance.stanreg
+
+
 
 
 
@@ -237,8 +245,10 @@ p_significance.brmsfit <- function(x, threshold = "default", effects = c("fixed"
     threshold = threshold
   )
 
-  out <- .prepare_output(data, insight::clean_parameters(x))
+  cleaned_parameters <- insight::clean_parameters(x)
+  out <- .prepare_output(data, cleaned_parameters)
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- class(data)
