@@ -1,11 +1,18 @@
 #' Region of Practical Equivalence (ROPE)
 #'
-#' Compute the proportion of the HDI (default to the 89\% HDI) of a posterior distribution that lies within a region of practical equivalence.
+#' Compute the proportion of the HDI (default to the `89%` HDI) of a posterior distribution that lies within a region of practical equivalence.
 #'
-#' @param x Vector representing a posterior distribution. Can also be a \code{stanreg} or \code{brmsfit} model.
-#' @param range ROPE's lower and higher bounds. Should be a vector of length two (e.g., \code{c(-0.1, 0.1)}) or \code{"default"}. If \code{"default"}, the range is set to \code{c(-0.1, 0.1)} if input is a vector, and based on \code{\link[=rope_range]{rope_range()}} if a Bayesian model is provided.
+#' @param x Vector representing a posterior distribution. Can also be a `stanreg` or `brmsfit` model.
+#' @param range ROPE's lower and higher bounds. Should be `"default"` or
+#' depending on the number of outcome variables a vector or a list. In models with one response,
+#' `range` should be a vector of length two (e.g., `c(-0.1, 0.1)`). In
+#' multivariate models, `range` should be a list with a numeric vectors for
+#' each response variable. Vector names should correspond to the name of the response
+#' variables. If `"default"` and input is a vector, the range is set to `c(-0.1,
+#' 0.1)`. If `"default"` and input is a Bayesian model,
+#' [`rope_range()`][rope_range] is used.
 #' @param ci The Credible Interval (CI) probability, corresponding to the proportion of HDI, to use for the percentage in ROPE.
-#' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See \code{\link{ci}}.
+#' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See [ci()].
 #'
 #' @inheritParams hdi
 #'
@@ -15,20 +22,20 @@
 #'   different from 0 does not make much sense (the probability of a single value
 #'   null hypothesis in a continuous distribution is 0). Therefore, the idea
 #'   underlining ROPE is to let the user define an area around the null value
-#'   enclosing values that are \emph{equivalent to the null} value for practical
+#'   enclosing values that are *equivalent to the null* value for practical
 #'   purposes (\cite{Kruschke 2010, 2011, 2014}).
 #'   \cr \cr
 #'   Kruschke (2018) suggests that such null value could be set, by default,
 #'   to the -0.1 to 0.1 range of a standardized parameter (negligible effect
 #'   size according to Cohen, 1988). This could be generalized: For instance,
-#'   for linear models, the ROPE could be set as \code{0 +/- .1 * sd(y)}.
+#'   for linear models, the ROPE could be set as `0 +/- .1 * sd(y)`.
 #'   This ROPE range can be automatically computed for models using the
-#'   \link{rope_range} function.
+#'   [rope_range] function.
 #'   \cr \cr
-#'   Kruschke (2010, 2011, 2014) suggests using the proportion of  the 95\%
-#'   (or 89\%, considered more stable) \link[=hdi]{HDI} that falls within the
+#'   Kruschke (2010, 2011, 2014) suggests using the proportion of  the `95%`
+#'   (or `89%`, considered more stable) [HDI][hdi] that falls within the
 #'   ROPE as an index for "null-hypothesis" testing (as understood under the
-#'   Bayesian framework, see \code{\link[=equivalence_test]{equivalence_test()}}).
+#'   Bayesian framework, see [`equivalence_test()`][equivalence_test]).
 #' }
 #' \subsection{Sensitivity to parameter's scale}{
 #'   It is important to consider the unit (i.e., the scale) of the predictors
@@ -47,21 +54,23 @@
 #'   on independence. Most problematic are parameters that only have partial
 #'   overlap with the ROPE region. In case of collinearity, the (joint) distributions
 #'   of these parameters may either get an increased or decreased ROPE, which
-#'   means that inferences based on \code{rope()} are inappropriate
+#'   means that inferences based on `rope()` are inappropriate
 #'   (\cite{Kruschke 2014, 340f}).
 #'   \cr \cr
-#'   \code{rope()} performs a simple check for pairwise correlations between
+#'   `rope()` performs a simple check for pairwise correlations between
 #'   parameters, but as there can be collinearity between more than two variables,
 #'   a first step to check the assumptions of this hypothesis testing is to look
 #'   at different pair plots. An even more sophisticated check is the projection
 #'   predictive variable selection (\cite{Piironen and Vehtari 2017}).
 #' }
 #' \subsection{Strengths and Limitations}{
-#'   \strong{Strengths:} Provides information related to the practical relevance of the effects.
+#'   **Strengths:** Provides information related to the practical relevance of the effects.
 #'   \cr \cr
-#'   \strong{Limitations:} A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
+#'   **Limitations:** A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
 #' }
 #'
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @references \itemize{
 #' \item Cohen, J. (1988). Statistical power analysis for the behavioural sciences.
 #' \item Kruschke, J. K. (2010). What to believe: Bayesian methods for data analysis. Trends in cognitive sciences, 14(7), 293-300. \doi{10.1016/j.tics.2010.05.001}.
@@ -79,7 +88,6 @@
 #' rope(x = rnorm(1000, 0, 1), range = c(-0.1, 0.1))
 #' rope(x = rnorm(1000, 1, 0.01), range = c(-0.1, 0.1))
 #' rope(x = rnorm(1000, 1, 1), ci = c(.90, .95))
-#'
 #' \dontrun{
 #' library(rstanarm)
 #' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
@@ -94,12 +102,16 @@
 #' rope(model)
 #' rope(model, ci = c(.90, .95))
 #'
+#' library(brms)
+#' model <- brms::brm(brms::mvbind(mpg, disp) ~ wt + cyl, data = mtcars)
+#' rope(model)
+#' rope(model, ci = c(.90, .95))
+#'
 #' library(BayesFactor)
 #' bf <- ttestBF(x = rnorm(100, 1, 1))
 #' rope(bf)
 #' rope(bf, ci = c(.90, .95))
 #' }
-#' @importFrom insight get_parameters is_multivariate
 #' @export
 rope <- function(x, ...) {
   UseMethod("rope")
@@ -124,7 +136,7 @@ rope.default <- function(x, ...) {
 
 #' @rdname rope
 #' @export
-rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.numeric <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   if (all(range == "default")) {
     range <- c(-0.1, 0.1)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
@@ -145,7 +157,7 @@ rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verb
   }
 
   # Attributes
-  hdi_area <- cbind(CI = ci * 100, data.frame(do.call(rbind, lapply(rope_values, attr, "HDI_area"))))
+  hdi_area <- cbind(CI = ci, data.frame(do.call(rbind, lapply(rope_values, attr, "HDI_area"))))
   names(hdi_area) <- c("CI", "CI_low", "CI_high")
 
   attr(out, "HDI_area") <- hdi_area
@@ -161,7 +173,7 @@ rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verb
 
 #' @rdname rope
 #' @export
-rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   out <- .prepare_rope_df(x, range, ci, ci_method, verbose)
   HDI_area_attributes <- .compact_list(out$HDI_area)
   dat <- data.frame(
@@ -178,33 +190,42 @@ rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", v
   dat
 }
 
+
+
 #' @rdname rope
 #' @export
-rope.emmGrid <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+rope.emmGrid <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+  xdf <- insight::get_parameters(x)
 
   dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(dat, "object_name") <- .safe_deparse(substitute(x))
   dat
 }
 
+#' @export
+rope.emm_list <- rope.emmGrid
+
 
 
 #' @rdname rope
 #' @export
-rope.BFBayesFactor <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+  if (all(range == "default")) {
+    range <- rope_range(x, verbose = verbose)
+  }
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
 
+#' @export
+rope.bamlss <- rope.BFBayesFactor
+
+
 #' @rdname rope
 #' @export
-rope.MCMCglmm <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
   out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -213,7 +234,7 @@ rope.MCMCglmm <- function(x, range = "default", ci = .89, ci_method = "HDI", ver
 
 
 #' @export
-rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   out <- rope(as.data.frame(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
   attr(out, "data") <- .safe_deparse(substitute(x))
@@ -223,8 +244,30 @@ rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose
 
 
 
+#' @export
+rope.bcplm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
+  out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+  attr(out, "object_name") <- NULL
+  attr(out, "data") <- .safe_deparse(substitute(x))
+  out
+}
+
+#' @export
+rope.bayesQR <- rope.bcplm
+
+#' @export
+rope.blrm <- rope.bcplm
+
+#' @export
+rope.BGGM <- rope.bcplm
+
+#' @export
+rope.mcmc.list <- rope.bcplm
+
+
+
 #' @keywords internal
-.rope <- function(x, range = c(-0.1, 0.1), ci = .89, ci_method = "HDI", verbose = TRUE) {
+.rope <- function(x, range = c(-0.1, 0.1), ci = 0.95, ci_method = "HDI", verbose = TRUE) {
   ci_bounds <- ci(x, ci = ci, method = ci_method, verbose = verbose)
 
   if (anyNA(ci_bounds)) {
@@ -237,7 +280,7 @@ rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose
 
 
   rope <- data.frame(
-    "CI" = ci * 100,
+    "CI" = ci,
     "ROPE_low" = range[1],
     "ROPE_high" = range[2],
     "ROPE_Percentage" = rope_percentage
@@ -253,56 +296,18 @@ rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose
 
 #' @rdname rope
 #' @export
-rope.stanreg <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
-  effects <- match.arg(effects)
-
-  if (all(range == "default")) {
-    range <- rope_range(x)
-  } else if (!all(is.numeric(range)) || length(range) != 2) {
-    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
-  }
-
-  # check for possible collinearity that might bias ROPE
-  if (verbose) .check_multicollinearity(x, "rope")
-
-  rope_data <- rope(
-    insight::get_parameters(x, effects = effects, parameters = parameters),
-    range = range,
-    ci = ci,
-    ci_method = ci_method,
-    verbose = verbose,
-    ...
-  )
-
-  out <- .prepare_output(rope_data, insight::clean_parameters(x))
-
-  attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
-  class(out) <- class(rope_data)
-
-  out
-}
-
-
-
-#' @rdname rope
-#' @export
-rope.brmsfit <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
+rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  if (insight::is_multivariate(x)) {
-    stop("Multivariate response models are not yet supported.")
-  }
-
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
 
   # check for possible collinearity that might bias ROPE
-  if (verbose) .check_multicollinearity(x, "rope")
+  if (verbose && !inherits(x, "blavaan")) .check_multicollinearity(x, "rope")
 
   rope_data <- rope(
     insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
@@ -313,7 +318,97 @@ rope.brmsfit <- function(x, range = "default", ci = .89, ci_method = "HDI", effe
     ...
   )
 
-  out <- .prepare_output(rope_data, insight::clean_parameters(x))
+  out <- .prepare_output(rope_data, insight::clean_parameters(x), inherits(x, "stanmvreg"))
+
+  attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  class(out) <- class(rope_data)
+
+  out
+}
+
+#' @export
+rope.stanfit <- rope.stanreg
+
+#' @export
+rope.blavaan <- rope.stanreg
+
+
+#' @rdname rope
+#' @export
+rope.brmsfit <- function(x,
+                         range = "default",
+                         ci = 0.95,
+                         ci_method = "HDI",
+                         effects = c("fixed", "random", "all"),
+                         component = c("conditional", "zi", "zero_inflated", "all"),
+                         parameters = NULL,
+                         verbose = TRUE,
+                         ...) {
+  effects <- match.arg(effects)
+  component <- match.arg(component)
+
+  # check range argument
+  if (all(range == "default")) {
+    range <- rope_range(x, verbose = verbose)
+    # we expect a list with named vectors (length two) in the multivariate case.
+    # Names state the response variable.
+  } else if (insight::is_multivariate(x)) {
+    if (
+      !is.list(range) ||
+      length(range) < length(insight::find_response(x)) ||
+      !all(names(range) %in% insight::find_response(x))
+    ) {
+      stop("With a multivariate model, `range` should be 'default' or a list of named numeric vectors with length 2.")
+    }
+  } else if (!all(is.numeric(range)) || length(range) != 2) {
+    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
+  }
+
+  # check for possible collinearity that might bias ROPE and print a warning
+  if (verbose) .check_multicollinearity(x, "rope")
+
+  # calc rope
+  if (insight::is_multivariate(x)) {
+    dv <- insight::find_response(x)
+
+    # ROPE range / width differs between response varialbe. Thus ROPE is
+    # calculated for every variable on its own.
+    rope_data <- lapply(
+      dv,
+      function(dv_item) {
+        ret <- rope(
+          insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+          range = range[[dv_item]],
+          ci = ci,
+          ci_method = ci_method,
+          verbose = verbose,
+          ...
+        )
+
+        # It's a waste of performance to calculate ROPE for all parameters
+        # with the ROPE width of a specific response variable and to throw
+        # away the unwanted results. However, performance impact should not be
+        # too high and this way it is much easier to handle the `parameters`
+        # argument.
+        ret[grepl(paste0("(.*)", dv_item), ret$Parameter), ]
+      }
+    )
+    rope_data <- do.call(rbind, rope_data)
+
+    out <- .prepare_output(rope_data, insight::clean_parameters(x), is_brms_mv = TRUE)
+  } else {
+    rope_data <- rope(
+      insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+      range = range,
+      ci = ci,
+      ci_method = ci_method,
+      verbose = verbose,
+      ...
+    )
+
+    out <- .prepare_output(rope_data, insight::clean_parameters(x))
+  }
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -325,11 +420,11 @@ rope.brmsfit <- function(x, range = "default", ci = .89, ci_method = "HDI", effe
 
 
 #' @export
-rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
 
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
@@ -361,8 +456,7 @@ rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", e
 
   dat <- do.call(rbind, args = c(.compact_list(list), make.row.names = FALSE))
 
-  dat <- switch(
-    effects,
+  dat <- switch(effects,
     fixed = .select_rows(dat, "Group", "fixed"),
     random = .select_rows(dat, "Group", "random"),
     dat
@@ -389,9 +483,9 @@ rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", e
 
 
 #' @export
-rope.sim <- function(x, range = "default", ci = .89, ci_method = "HDI", parameters = NULL, verbose = TRUE, ...) {
+rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "HDI", parameters = NULL, verbose = TRUE, ...) {
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
