@@ -8,7 +8,6 @@
 }
 
 #' @keywords internal
-#' @importFrom insight get_parameters
 .clean_priors_and_posteriors.stanreg <- function(posterior, prior,
                                                  verbose = TRUE,
                                                  effects, component, ...) {
@@ -19,7 +18,7 @@
 
 
   prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-  if (is(prior, "try-error")) {
+  if (methods::is(prior, "try-error")) {
     if (grepl("flat priors", prior)) {
       prior <- paste0(
         prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -43,14 +42,33 @@
 #' @keywords internal
 .clean_priors_and_posteriors.brmsfit <- .clean_priors_and_posteriors.stanreg
 
+
 #' @keywords internal
-#' @importFrom stats update
-.clean_priors_and_posteriors.emmGrid <- function(posterior, prior,
-                                                 verbose = TRUE) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
+.clean_priors_and_posteriors.blavaan <- function(posterior, prior,
+                                                 verbose = TRUE, ...) {
+  # Get Priors
+  if (is.null(prior)) {
+    prior <- posterior
   }
 
+  prior <- unupdate(prior, verbose = verbose)
+
+  prior <- insight::get_parameters(prior)
+  posterior <- insight::get_parameters(posterior)
+
+  list(
+    posterior = posterior,
+    prior = prior
+  )
+}
+
+
+#' @keywords internal
+.clean_priors_and_posteriors.emmGrid <- function(posterior,
+                                                 prior,
+                                                 verbose = TRUE) {
+  insight::check_if_installed("emmeans")
+
   if (is.null(prior)) {
     prior <- posterior
     warning(
@@ -59,7 +77,7 @@
     )
   } else if (!inherits(prior, "emmGrid")) { # then is it a model
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-    if (is(prior, "try-error")) {
+    if (methods::is(prior, "try-error")) {
       if (grepl("flat priors", prior)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -102,7 +120,7 @@
     )
   } else if (!inherits(prior, "emm_list")) {
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
-    if (is(prior, "try-error")) {
+    if (methods::is(prior, "try-error")) {
       if (grepl("flat priors", prior)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
@@ -141,12 +159,15 @@
 # BMA ---------------------------------------------------------------------
 
 #' @keywords internal
-#' @importFrom stats as.formula terms terms.formula
 .get_model_table <- function(BFGrid, priorOdds = NULL, add_effects_table = TRUE, ...) {
   denominator <- attr(BFGrid, "denominator")
   BFGrid <- rbind(BFGrid[denominator, ], BFGrid[-denominator, ])
   attr(BFGrid, "denominator") <- 1
 
+  # This looks like it does nothing, but this is needed to prevent Inf in large BFs.
+  # Small BFs are better than large BFs
+  BFGrid <- stats::update(BFGrid, reference = "top")
+
   # Prior and post odds
   Modelnames <- BFGrid$Model
   if (!is.null(priorOdds)) {
@@ -155,15 +176,17 @@
     priorOdds <- rep(1, length(Modelnames))
   }
 
-  posterior_odds <- priorOdds * BFGrid$BF
+  prior_logodds <- log(priorOdds)
+  posterior_logodds <- prior_logodds + BFGrid$log_BF
 
-  priorProbs <- priorOdds / sum(priorOdds)
-  postProbs <- posterior_odds / sum(posterior_odds)
+  # norm
+  prior_logodds <- prior_logodds - log(sum(exp(prior_logodds)))
+  posterior_logodds <- posterior_logodds - log(sum(exp(posterior_logodds)))
 
   df.model <- data.frame(
     Modelnames,
-    priorProbs,
-    postProbs,
+    priorProbs = exp(prior_logodds),
+    postProbs = exp(posterior_logodds),
     stringsAsFactors = FALSE
   )
 
@@ -231,14 +254,15 @@
 
 # make_BF_plot_data -------------------------------------------------------
 
-#' @importFrom stats median mad approx
-#' @importFrom utils stack
 #' @keywords internal
-.make_BF_plot_data <- function(posterior, prior, direction, null,
-                               extend_scale = 0.05, precision = 2^8, ...) {
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
+.make_BF_plot_data <- function(posterior,
+                               prior,
+                               direction,
+                               null,
+                               extend_scale = 0.05,
+                               precision = 2^8,
+                               ...) {
+  insight::check_if_installed("logspline")
 
   estimate_samples_density <- function(samples) {
     nm <- .safe_deparse(substitute(samples))
@@ -273,7 +297,7 @@
       # 3. direction?
       if (direction > 0) {
         d_points <- d_points[d_points$x >= min(null), , drop = FALSE]
-        if (is.infinite(min(null))){
+        if (is.infinite(min(null))) {
           norm_factor <- 1
         } else {
           norm_factor <- 1 - logspline::plogspline(min(null), f_x)
@@ -282,7 +306,7 @@
         d_null$y <- d_null$y / norm_factor
       } else if (direction < 0) {
         d_points <- d_points[d_points$x <= max(null), , drop = FALSE]
-        if (is.infinite(max(null))){
+        if (is.infinite(max(null))) {
           norm_factor <- 1
         } else {
           norm_factor <- logspline::plogspline(max(null), f_x)
@@ -356,9 +380,7 @@ as.double.bayesfactor_restricted <- as.numeric.bayesfactor_inclusion
 
 #' @keywords internal
 .logspline <- function(x, ...) {
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
+  insight::check_if_installed("logspline")
 
   # arg_names <- names(formals(logspline::logspline, envir = parent.frame()))
   arg_names <- names(formals(logspline::logspline)) # support R<3.6.0
