@@ -4,7 +4,7 @@ if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
     p <- insight::get_parameters(m, effects = "all")
 
     test_that("point_estimate", {
-      testthat::expect_equal(
+      expect_equal(
         point_estimate(m, effects = "all")$Median,
         point_estimate(p)$Median,
         tolerance = 1e-3
@@ -15,7 +15,7 @@ if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
     p <- insight::get_parameters(m, effects = "all", component = "all")
 
     test_that("point_estimate", {
-      testthat::expect_equal(
+      expect_equal(
         point_estimate(m, effects = "all", component = "all")$Median,
         point_estimate(p)$Median,
         tolerance = 1e-3
