@@ -1,14 +1,14 @@
-if (require("rstanarm") && require("bayestestR") && require("testthat")) {
-
+if (require("rstanarm") && suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) &&
+  require("testthat") && require("emmeans")) {
   test_that("si.numeric", {
     set.seed(333)
     prior <- distribution_normal(1000, mean = 0, sd = 1)
     posterior <- distribution_normal(1000, mean = .5, sd = .3)
 
     res <- si(posterior, prior)
-    expect_equal(res$CI_low, 0.039, tolerance = 0.02)
-    expect_equal(res$CI_high, 1.053, tolerance = 0.02)
-    expect_is(res, c("bayestestR_si"))
+    expect_equal(res$CI_low, 0.03999124, tolerance = 0.02)
+    expect_equal(res$CI_high, 1.053103, tolerance = 0.02)
+    expect_s3_class(res, c("bayestestR_si"))
 
     res <- si(posterior, prior, BF = 3)
     expect_equal(res$CI_low, 0.333, tolerance = 0.02)
@@ -27,7 +27,8 @@ if (require("rstanarm") && require("bayestestR") && require("testthat")) {
   test_that("si.rstanarm", {
     skip_on_cran()
 
-    contrasts(sleep$group) <- contr.bayes # See vignette
+    data(sleep)
+    contrasts(sleep$group) <- contr.orthonorm # See vignette
     stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep, refresh = 0)
 
     set.seed(333)
@@ -37,7 +38,14 @@ if (require("rstanarm") && require("bayestestR") && require("testthat")) {
     set.seed(333)
     res2 <- si(stan_model, verbose = FALSE)
 
-    expect_is(res1, c("bayestestR_si"))
+    expect_s3_class(res1, c("bayestestR_si"))
     expect_equal(res1, res2)
+
+    set.seed(123)
+    group_diff <- pairs(emmeans(stan_model, ~group))
+    res3 <- si(group_diff, prior = stan_model)
+
+    expect_equal(res3$CI_low, -2.746, tolerance = 0.3)
+    expect_equal(res3$CI_high, -0.4, tolerance = 0.3)
   })
 }
